import { useApi, microsoftAuthApiRef, githubAuthApiRef, googleAuthApiRef, bitbucketAuthApiRef } from '@backstage/core-plugin-api';
import { useState, useCallback } from 'react';
import { useAsync } from 'react-use';

const oauthApiRefMap = {
  microsoft: microsoftAuthApiRef,
  github: githubAuthApiRef,
  google: googleAuthApiRef,
  bitbucket: bitbucketAuthApiRef
};
const useOauthSignIn = ({ provider, scopes }) => {
  const authApi = useApi(oauthApiRefMap[provider ?? "github"]);
  const [isSignedIn, setSignedIn] = useState(false);
  const [token, setToken] = useState("");
  const [forceLogin, setForceLogin] = useState(false);
  const doSignIn = useCallback(
    async (usePopup = true) => {
      const accessToken = await authApi.getAccessToken(scopes, {
        optional: !usePopup,
        instantPopup: usePopup
      });
      if (accessToken) {
        setSignedIn(!!accessToken);
        setToken(accessToken);
      }
    },
    [authApi, setSignedIn, scopes]
  );
  const { loading, error } = useAsync(async () => {
    if (!isSignedIn) {
      await doSignIn(forceLogin);
    }
  }, [doSignIn, forceLogin, isSignedIn]);
  const showSignInModal = useCallback(() => {
    setForceLogin(true);
  }, [setForceLogin]);
  return { token, loading, error, isSignedIn, showSignInModal };
};

export { useOauthSignIn };
//# sourceMappingURL=useOauthSignIn.esm.js.map
